#...
Displaying notes found in: .note.gnu.property
  Owner                 Data size	Description
  GNU                  0x[0-9a-f]+	NT_GNU_PROPERTY_TYPE_0
      Properties: stack size: 0x800000
	x86 ISA needed: CMOV, SSE
	x86 ISA used: SSE, SSE3
	x86 feature used: x86
#pass
