.*: Assembler messages:
.*:4: Error: .* `addsd'
.*:5: Error: .* `vaddsd'
.*:6: Error: .* `vaddsd'
.*:8: Error: .* `addss'
.*:9: Error: .* `vaddss'
.*:10: Error: .* `vaddss'
.*:12: Error: .* `vbroadcastf32x2'
.*:13: Error: .* `vbroadcastf32x2'
.*:15: Error: .* `vbroadcasti32x2'
.*:16: Error: .* `vbroadcasti32x2'
.*:17: Error: .* `vbroadcasti32x2'
.*:19: Error: .* `vbroadcastsd'
.*:20: Error: .* `vbroadcastsd'
.*:21: Error: .* `vbroadcastsd'
.*:23: Error: .* `vbroadcastss'
.*:24: Error: .* `vbroadcastss'
.*:25: Error: .* `vbroadcastss'
.*:26: Error: .* `vbroadcastss'
.*:27: Error: .* `vbroadcastss'
.*:29: Error: .* `cvtdq2pd'
.*:30: Error: .* `vcvtdq2pd'
.*:31: Error: .* `vcvtdq2pd'
.*:33: Error: .* `vcvtph2ps'
.*:34: Error: .* `vcvtph2ps'
.*:36: Error: .* `cvtps2pd'
.*:37: Error: .* `vcvtps2pd'
.*:38: Error: .* `vcvtps2pd'
.*:40: Error: .* `vcvtps2ph'
.*:41: Error: .* `vcvtps2ph'
.*:43: Error: .* `vcvtudq2pd'
.*:45: Error: .* `insertps'
.*:46: Error: .* `vinsertps'
.*:47: Error: .* `vinsertps'
.*:49: Error: .* `movddup'
.*:50: Error: .* `vmovddup'
.*:51: Error: .* `vmovddup'
.*:53: Error: .* `vpbroadcastb'
.*:54: Error: .* `vpbroadcastb'
.*:55: Error: .* `vpbroadcastb'
.*:56: Error: .* `vpbroadcastb'
.*:57: Error: .* `vpbroadcastb'
.*:59: Error: .* `vpbroadcastd'
.*:60: Error: .* `vpbroadcastd'
.*:61: Error: .* `vpbroadcastd'
.*:62: Error: .* `vpbroadcastd'
.*:63: Error: .* `vpbroadcastd'
.*:65: Error: .* `vpbroadcastq'
.*:66: Error: .* `vpbroadcastq'
.*:67: Error: .* `vpbroadcastq'
.*:68: Error: .* `vpbroadcastq'
.*:69: Error: .* `vpbroadcastq'
.*:71: Error: .* `vpbroadcastw'
.*:72: Error: .* `vpbroadcastw'
.*:73: Error: .* `vpbroadcastw'
.*:74: Error: .* `vpbroadcastw'
.*:75: Error: .* `vpbroadcastw'
.*:77: Error: .* `pmovsxbd'
.*:78: Error: .* `vpmovsxbd'
.*:79: Error: .* `vpmovsxbd'
.*:80: Error: .* `vpmovsxbd'
.*:81: Error: .* `vpmovsxbd'
.*:83: Error: .* `pmovsxbq'
.*:84: Error: .* `vpmovsxbq'
.*:85: Error: .* `vpmovsxbq'
.*:86: Error: .* `vpmovsxbq'
.*:87: Error: .* `vpmovsxbq'
.*:88: Error: .* `vpmovsxbq'
.*:90: Error: .* `pmovsxdq'
.*:91: Error: .* `vpmovsxdq'
.*:92: Error: .* `vpmovsxdq'
.*:94: Error: .* `pmovsxwd'
.*:95: Error: .* `vpmovsxwd'
.*:96: Error: .* `vpmovsxwd'
.*:98: Error: .* `pmovsxwq'
.*:99: Error: .* `vpmovsxwq'
.*:100: Error: .* `vpmovsxwq'
.*:101: Error: .* `vpmovsxwq'
.*:102: Error: .* `vpmovsxwq'
.*:104: Error: .* `pmovzxbd'
.*:105: Error: .* `vpmovzxbd'
.*:106: Error: .* `vpmovzxbd'
.*:107: Error: .* `vpmovzxbd'
.*:108: Error: .* `vpmovzxbd'
.*:110: Error: .* `pmovzxbq'
.*:111: Error: .* `vpmovzxbq'
.*:112: Error: .* `vpmovzxbq'
.*:113: Error: .* `vpmovzxbq'
.*:114: Error: .* `vpmovzxbq'
.*:115: Error: .* `vpmovzxbq'
.*:117: Error: .* `pmovzxdq'
.*:118: Error: .* `vpmovzxdq'
.*:119: Error: .* `vpmovzxdq'
.*:121: Error: .* `pmovzxwd'
.*:122: Error: .* `vpmovzxwd'
.*:123: Error: .* `vpmovzxwd'
.*:125: Error: .* `pmovzxwq'
.*:126: Error: .* `vpmovzxwq'
.*:127: Error: .* `vpmovzxwq'
.*:128: Error: .* `vpmovzxwq'
.*:129: Error: .* `vpmovzxwq'
.*:131: Error: .* `vcvtps2qq'
.*:132: Error: .* `vcvtps2uqq'
.*:133: Error: .* `vcvttps2qq'
.*:134: Error: .* `vcvttps2uqq'
.*:136: Error: .* `movq'
.*:137: Error: .* `vmovq'
.*:138: Error: .* `vmovq'
.*:140: Error: .* `movq'
.*:141: Error: .* `vmovq'
.*:142: Error: .* `vmovq'
