.*: Assembler messages:
.*:10: Error: branch to a symbol in another ISA mode
.*:12: Error: branch to a symbol in another ISA mode
.*:14: Error: branch to a symbol in another ISA mode
.*:16: Error: branch to a symbol in another ISA mode
.*:18: Error: branch to a symbol in another ISA mode
.*:20: Error: branch to a symbol in another ISA mode
.*:22: Error: branch to a symbol in another ISA mode
.*:24: Error: branch to a symbol in another ISA mode
.*:26: Error: branch to a symbol in another ISA mode
.*:34: Error: branch to misaligned address \(0x10b5\)
.*:38: Error: branch to misaligned address \(0x10b7\)
.*:42: Error: branch to a symbol in another ISA mode
.*:44: Error: branch to a symbol in another ISA mode
.*:46: Error: branch to a symbol in another ISA mode
.*:48: Error: branch to a symbol in another ISA mode
.*:50: Error: branch to a symbol in another ISA mode
.*:52: Error: branch to a symbol in another ISA mode
.*:54: Error: branch to a symbol in another ISA mode
.*:56: Error: branch to a symbol in another ISA mode
.*:58: Error: branch to a symbol in another ISA mode
.*:66: Error: branch to misaligned address \(0x10b5\)
.*:70: Error: branch to misaligned address \(0x10b7\)
