#as:
#objdump: -dw -Mintel
#name: i386 WAITPKG insns (Intel disassembly)
#source: waitpkg.s

.*: +file format .*


Disassembly of section \.text:

00000000 <_start>:
[ 	]*[a-f0-9]+:[ 	]*f3 0f ae f0[ 	]*umonitor eax
[ 	]*[a-f0-9]+:[ 	]*67 f3 0f ae f1[ 	]*umonitor cx
[ 	]*[a-f0-9]+:[ 	]*f2 0f ae f1[ 	]*umwait ecx
[ 	]*[a-f0-9]+:[ 	]*66 0f ae f1[ 	]*tpause ecx
#pass
