SCRIPT_NAME=elf
MACHINE=
TEMPLATE_NAME=elf32
OUTPUT_FORMAT="elf32-or1k"
NOP=0x15000000
TEXT_START_ADDR=0x0000
TARGET_PAGE_SIZE=0x2000
MAXPAGESIZE="CONSTANT (MAXPAGESIZE)"
EMBEDDED=yes
ARCH=or1k
ELFSIZE=32
INITIAL_READONLY_SECTIONS=".vectors ${RELOCATING-0} : { KEEP (*(.vectors)) }"
NO_REL_RELOCS=yes
COMMONPAGESIZE="CONSTANT (COMMONPAGESIZE)"
