.*: Assembler messages:
.*:2: Error: invalid register range `lwm \$16-17,0\(\$4\)'
.*:3: Error: invalid operands `lwm \$17-\$16,0\(\$4\)'
.*:4: Error: invalid operands `lwm \$16-\$f17,0\(\$4\)'
.*:5: Error: invalid operands `lwm \$f16-\$17,0\(\$4\)'
.*:6: Error: floating-point expression required `li\.s \$4,foo'
.*:7: Error: cannot create floating-point number
.*:8: Error: floating-point expression required `li\.s \$4,\$4'
.*:9: Error: invalid operands `li\.s 1.0'
