	.text
trap:
        trap
        twlt    1, 2
        twle    3, 4
        tweq    0, 1
        twge    2, 3
        twgt    2, 4
        twnl    2, 5
        twne    2, 6
        twng    2, 7
        twllt   2, 8
        twlle   2, 9
        twlge   2, 10
        twlgt   2, 11
        twlnl   2, 12
        twlng   2, 13

